from django.forms.widgets import Widget
from django.template import loader
from django.utils.safestring import mark_safe

from jsonschemaform.default_settings import settings as conf
from django.conf import settings

import json


conf.update(getattr(settings, 'JSONSCHEMAFORM', {}))


class JSONSchemaWidget(Widget):

    template_name = 'jsonschema_widget.html'

    def __init__(self, sch, attrs=None):
        attrs = attrs or {}
        self.schema = sch
        super(JSONSchemaWidget, self).__init__(attrs)

    def get_context(self, name, value, attrs=None):
        opt = conf.get('options')
        opt.update({'startval': json.loads(value)})
        return {
            'id': attrs.get('id'),
            'name': name,
            'context': json.dumps({
                'id': attrs.get('id'),
                'attrs': attrs,
                'schema': self.schema,
                'options': opt
            })
        }

    def render(self, name, value, attrs=None):
        context = self.get_context(name, value, attrs)
        template = loader.get_template(self.template_name).render(context)
        return mark_safe(template)

    class Media(object):
        js = (
            'js/jsonschema-form.js',
            'js/jsoneditor.min.js',
        )
        css = conf.get('css')



settings = {
    'css': {
        'all': (
            'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css',
        )
    },
    'options': {
        'theme': 'bootstrap3',
        'iconlib': 'bootstrap3',
        'no_additional_properties': True,
    }
}


"""
The default configuration can be overriten in django settings:
To a better undestanding on this options plese refer to: https://github.com/jdorn/json-editor#options
"""

# JSONSCHEMAFORM = {
#     'css': {
#         'all': (
#             'https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css',
#         )
#     },
#     'options': {
#         'ajax': False,
#         'disable_array_add': False,
#         'disable_array_delete': False,
#         'disable_array_reorder': False,
#         'disable_collapse': False,
#         'disable_edit_json': False,
#         'disable_properties': False,
#         'form_name_root': 'root',
#         'iconlib': None,
#         'no_additional_properties': False,
#         'refs': {},
#         'required_by_default': False,
#         'keep_oneof_values': True,
#         'schema': {},
#         'show_errors': "interaction",
#         'startval': None,
#         'template': 'default',
#         'theme': 'html',
#         'display_required_only': False
#     }
# }



from setuptools import find_packages
from setuptools import setup

setup(
    author="Collabo Software Ltda",
    author_email="basask@collabo.com.br",
    description="Django admin widgets to render jsonschema as forms",
    name="django-jsonschema-form",
    long_description="Django admin widgets to render jsonschema as forms",
    version="1.0.2",
    url="https://www.collabo.com.br/",
    license="MIT",
    packages=find_packages(),
    install_requires=[],
    include_package_data=True,
    package_data={
        'jsonschemaform': ['templates/*.html', 'static/**/*.js'],
    },
    classifiers=[
        "Development Status :: 4 - Beta",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ]
)
